# oscillode
# Copyright (C) 2024 oscillode Project Contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# blender_maxwell
# Copyright (C) 2024 blender_maxwell Project Contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from blender_maxwell.utils import bl_cache

from ... import contracts as ct
from .. import base

FK = ct.FlowKind
FS = ct.FlowSignal


class MaxwellMonitorBLSocket(base.MaxwellSimSocket):
	socket_type = ct.SocketType.MaxwellMonitor
	bl_label = 'Maxwell Monitor'

	@bl_cache.cached_bl_property()
	def array(self) -> list:
		return []

	@bl_cache.cached_bl_property()
	def lazy_func(self) -> ct.FuncFlow | FS:
		if self.active_kind is FK.Array:
			return ct.FuncFlow(func=list)
		return FS.NoFlow

	@bl_cache.cached_bl_property()
	def params(self) -> ct.ParamsFlow:
		if self.active_kind is FK.Array:
			return ct.ParamsFlow()
		return FS.NoFlow


####################
# - Socket Configuration
####################
class MaxwellMonitorSocketDef(base.SocketDef):
	socket_type: ct.SocketType = ct.SocketType.MaxwellMonitor

	def init(self, bl_socket: MaxwellMonitorBLSocket) -> None:
		pass

	def local_compare(self, _: MaxwellMonitorBLSocket) -> None:
		return True


####################
# - Blender Registration
####################
BL_REGISTER = [
	MaxwellMonitorBLSocket,
]
